import applySpec from 'ramda/src/applySpec';
import compose from 'ramda/src/compose';
import pathOr from 'ramda/src/pathOr';
import propOr from 'ramda/src/propOr';

import { BASE_HERO_PROPS } from './base-hero';
import { HeroTypeName, HeroVariants } from '../types';
import { parseJsonString } from '../../utils';

const getVideoUrl = (hero: Record<string, any>) => {
    if (hero?.image) {
        const asset = parseJsonString(hero.image)?.image?.[0];
        if (asset?.selected?.type === 'VIDEO') {
            return asset?.selected.previewUrls?.[0];
        }
    }
    return '';
};

const getHeroBannerModel = applySpec({
    ...BASE_HERO_PROPS,
    videoUrl: getVideoUrl,
    textAlignment: propOr('start', HeroTypeName.textAlignment),
    backgroundScrim: propOr(false, HeroTypeName.backgroundScrim)
});

export const getHeroBannerData = compose(getHeroBannerModel, pathOr({}, [HeroVariants.HeroBanner]));
